<?xml version="1.0" encoding="UTF-8"?>
<!-- ========================================================================= -->
<!--                                                                           -->
<!-- PDFUnit - Automated PDF Tests                                             -->
<!--                                                                           -->
<!-- Copyright (C) 2015 PDFUnit.com                                            -->
<!--                                                                           -->
<!-- This file is part of the commercial library PDFUnit.                      -->
<!--                                                                           -->
<!-- Legal information__: http://www.pdfunit.com/en/licensing.html             -->
<!-- Manual_____________: http://pdfunit.com/en/documentation/                 -->
<!-- Contact for license: license[at]pdfunit.com                               -->
<!--                                                                           -->
<!-- ========================================================================= -->
<!-- $Id: main.xslt 3736 2015-12-11 12:30:28Z csiedentop $
<!-  ========================================================================= -->
<xsl:stylesheet version="2.0" 
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:p="http://www.pdfunit.com"
>

  <!-- ============================================================ -->
  <!-- Declartion of constants.                                     -->
  <!-- ============================================================ -->
  <xsl:variable name="className">
    <xsl:value-of select="substring-before($fileName, '.')"/>
  </xsl:variable>

  <xsl:variable name="packageName">
    <xsl:value-of select="/p:pdfunit/p:header/@namespace" />
  </xsl:variable>

  <!-- ============================================================ -->
  <!-- Begin of the source generation.                              -->
  <!-- ============================================================ -->
  <xsl:template match="/">
    <xsl:call-template name="generateHeader" />
    <xsl:call-template name="generateImports" />
    <xsl:call-template name="generateComment" />
    <xsl:call-template name="generateClassBegin" />
    <xsl:apply-templates select="p:pdfunit/p:testcase"/>
    <xsl:call-template name="generateClassEnd" />
  </xsl:template>

  <!-- ============================================================ -->
  <!-- Template to generate all of the testcase-independant code.   -->
  <!-- ============================================================ -->
  <xsl:template match="p:testcase">
    <xsl:if test="@ignore">
      <xsl:text>  @Ignore("</xsl:text>
      <xsl:value-of select="@ignore"/>
      <xsl:text>")</xsl:text>
      <xsl:value-of select="$BREAK" />  
    </xsl:if>
    <xsl:choose>
      <xsl:when test="@errorExpected">
        <xsl:text>  @Test(expected=PDFUnitValidationException.class)</xsl:text>
      </xsl:when>
      <xsl:otherwise>
        <xsl:text>  @Test</xsl:text>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:value-of select="$BREAK" />
    <xsl:text>  public void </xsl:text>
    <xsl:value-of select="@name" />
    <xsl:text>() throws Exception {</xsl:text>
    <xsl:value-of select="$BREAK" />  

    <xsl:call-template name="generateFilenameTestDocument" />
    <xsl:call-template name="generateFilenameMasterDocument" />
    <xsl:value-of select="$BREAK" />
    <!-- Generate code for all the inner elements of &lt;assertThat&gt; -->
    <xsl:apply-templates select="*" />
    
    <xsl:text>    ;</xsl:text>
    <xsl:value-of select="$BREAK" />  
    <xsl:text>  }</xsl:text>
    <xsl:value-of select="$EMPTY_LINE" />  
  </xsl:template>

  <xsl:template match="p:assertThat">
    <xsl:text>    AssertThat.document(filename</xsl:text>
    <xsl:apply-templates select="@testPassword" />
    <xsl:text>)</xsl:text>
    <xsl:value-of select="$BREAK" />  
    <xsl:apply-templates select="@masterDocument" />
    <xsl:apply-templates select="*"/>
  </xsl:template>


  <xsl:template name="generateHeader">
    <xsl:text>package </xsl:text>
    <xsl:value-of select="$packageName" />
    <xsl:text>;</xsl:text>
    <xsl:value-of select="$EMPTY_LINE" />  
  </xsl:template>
  
  <xsl:template name="generateImports">
    <xsl:text>import static com.pdfunit.Constants.*;</xsl:text>
    <xsl:value-of select="$BREAK" />  
    <xsl:text>import com.pdfunit.*;</xsl:text>
    <xsl:value-of select="$BREAK" />  
    <xsl:text>import com.pdfunit.pagefilter.*;</xsl:text>
    <xsl:value-of select="$BREAK" />  
    <xsl:text>import com.pdfunit.errors.*;</xsl:text>
    <xsl:value-of select="$BREAK" />  
    <xsl:text>import com.pdfunit.util.*;</xsl:text>
    <xsl:value-of select="$BREAK" />
    <xsl:text>import java.awt.image.BufferedImage;</xsl:text>
    <xsl:value-of select="$BREAK" />  
    <xsl:text>import java.io.*;</xsl:text>
    <xsl:value-of select="$BREAK" />  
    <xsl:text>import java.util.*;</xsl:text>
    <xsl:value-of select="$BREAK" />  
    <xsl:text>import org.junit.*;</xsl:text>
    <xsl:value-of select="$BREAK" />  
    <xsl:text>import java.net.*;</xsl:text>
    <xsl:value-of select="$EMPTY_LINE" />  
  </xsl:template>
  
  <xsl:template name="generateComment">
    <xsl:text>/**</xsl:text>
    <xsl:value-of select="$BREAK" />  
    <xsl:value-of select="$JAVADOC_LINE_START" />  
    <xsl:value-of select="$BREAK" />
    <xsl:value-of select="$JAVADOC_LINE_START" />  
    <xsl:value-of select="normalize-space(/p:pdfunit/p:comment)" />
    <xsl:value-of select="$BREAK" />  
    <xsl:value-of select="$JAVADOC_LINE_START" />  
    <xsl:value-of select="$BREAK" />
    <xsl:value-of select="$JAVADOC_LINE_START" />  
    <xsl:text>This file is generated from </xsl:text>
    <xsl:value-of select="$fileName" />
    <xsl:text>.</xsl:text>
    <xsl:value-of select="$BREAK" />  
    <xsl:value-of select="$JAVADOC_LINE_START" />  
    <xsl:value-of select="$BREAK" />  
    
    <xsl:value-of select="$JAVADOC_LINE_START" />  
    <xsl:text>@since </xsl:text>
    <xsl:value-of select="/p:pdfunit/p:header/@date"/>
    <xsl:value-of select="$BREAK" />  

    <xsl:value-of select="$JAVADOC_LINE_START" />  
    <xsl:text>@author </xsl:text>
    <xsl:value-of select="/p:pdfunit/p:header/@author" />  
    <xsl:value-of select="$BREAK" />  

    <xsl:value-of select="$JAVADOC_LINE_START" />  
    <xsl:text>@version PDFUnit-XML: </xsl:text>
    <xsl:value-of select="/p:pdfunit/@version"/>
    <xsl:value-of select="$BREAK" />
    
    <xsl:value-of select="$JAVADOC_LINE_START" />  
    <xsl:text>@see www.pdfunit.com</xsl:text>

    <xsl:value-of select="$BREAK" />  
    <xsl:value-of select="$JAVADOC_LINE_START" />  
    <xsl:value-of select="$BREAK" />  
    <xsl:text> */</xsl:text>
    <xsl:value-of select="$BREAK" />  
  </xsl:template>
  
  <xsl:template name="generateClassBegin">
    <xsl:text>public class </xsl:text>
    <xsl:value-of select="$className" />
    <xsl:text> {</xsl:text>
    <xsl:value-of select="$EMPTY_LINE" />  
  </xsl:template>
  
  <xsl:template name="generateClassEnd">
    <xsl:text>}</xsl:text>
    <xsl:value-of select="$BREAK" />  
  </xsl:template>

  <xsl:template name="generateFilenameTestDocument">
    <xsl:choose>
      <xsl:when test="p:assertThat/@testIsURL">
        <xsl:text>    URL filename = new URL("</xsl:text>
        <xsl:value-of select="p:assertThat/@testDocument" />  
        <xsl:text>");</xsl:text>
        <xsl:value-of select="$BREAK" />
      </xsl:when>
      <xsl:otherwise>
        <xsl:text>    String filename = "</xsl:text>
        <xsl:value-of select="p:assertThat/@testDocument" />  
        <xsl:text>";</xsl:text>
        <xsl:value-of select="$BREAK" />
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template name="generateFilenameMasterDocument">
    <xsl:choose>
      <xsl:when test="p:assertThat/@masterIsURL">
        <xsl:text>    URL filenameMaster = new URL("</xsl:text>
        <xsl:value-of select="p:assertThat/@masterDocument" />  
        <xsl:text>");</xsl:text>
        <xsl:value-of select="$BREAK" />
      </xsl:when>
      <xsl:otherwise>
        <xsl:text>    String filenameMaster = "</xsl:text>
        <xsl:value-of select="p:assertThat/@masterDocument" />  
        <xsl:text>";</xsl:text>
        <xsl:value-of select="$BREAK" />
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template match="@testPassword | @masterPassword | @withPassword">
    <xsl:text>, "</xsl:text>
    <xsl:value-of select="." /> 
    <xsl:text>"</xsl:text>
  </xsl:template>
  
  <xsl:template match="p:assertThat/@masterDocument">
    <xsl:text>              .and(filenameMaster</xsl:text>
    <xsl:apply-templates select="../@masterPassword"/>
    <xsl:text>)</xsl:text>
    <xsl:value-of select="$BREAK" />
  </xsl:template>
  
  <xsl:template match="text()" priority="-99" >
  </xsl:template>

</xsl:stylesheet>